<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/**
 * Ticket Status display field
 * Use it $this->loadAnyTemplate('admin:com_ats/Common/TicketStatus', $params)
 *
 * $params is an array defining the following keys (they are expanded into local scope vars automatically):
 *
 * @var \Akeeba\TicketSystem\Admin\Model\Tickets $item          The current row
 * @var bool                                     $create_span   Should I wrap the output in a span?
 *
 * Variables made automatically available to us by FOF:
 *
 * @var \FOF30\View\DataView\Raw $this
 */

defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Select;
use Joomla\CMS\Language\Text;

$standard = ['O', 'P', 'C'];
$custom   = Select::getCustomTicketStatuses();

// Sanity check
if (!in_array($item->status, $standard) && !isset($custom[$item->status]))
{
    echo '';
    return;
}

if(in_array($item->status, $standard))
{
	$text  = Text::_('COM_ATS_TICKETS_STATUS_'.$item->status);
}
elseif(isset($custom[$item->status]))
{
	$text = $custom[$item->status];
}

$class = Html::getStatusClass($item->status);
$html = $text;

if($create_span)
{
	$html = '<span class="ats-status '.$class.'">'.$text.'</span>';
}
?>
{{ $html  }}